#
# spec file for package nlopt
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           nlopt
Version:        2.4.2
Release:        5.1
Summary:        A library for nonlinear optimization
License:        LGPL-2.0-only
Group:          Development/Libraries/C and C++
URL:            http://ab-initio.mit.edu/wiki/index.php/NLopt
Source0:        http://ab-initio.mit.edu/nlopt/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM nlopt-2.3-pkgconfig.patch
Patch1:         nlopt-2.3-pkgconfig.patch
# PATCH-FIX-UPSTREAM pythondir.patch
Patch2:         pythondir.patch
# PATCH-FIX-UPSTREAM nlopt-octave-4.0.patch -- https://github.com/stevengj/nlopt/issues/33
Patch3:         nlopt-octave-4.0.patch
# PATCH-FIX-UPSTREAM nlopt-octave4.4-prefixdir.patch badshah400@opensuse.org -- Fix how to find octave's prefix dir in configure.ac: octave-config no longer supports the keyword PREFIX and uses OCTAVE_HOME in its stead; patch being sent upstream
Patch4:         nlopt-octave4.4-prefixdir.patch
# PATCH-FIX-UPSTREAM nlopt-octave4.4-do_multi_index_op.patch badshah400@opensuse.org -- Replace do_multi_index_op by feval; the former is dropped from octave 4.4; patch being sent upstream
Patch5:         nlopt-octave4.4-do_multi_index_op.patch
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hdf5-devel
BuildRequires:  octave-devel
BuildRequires:  pkgconfig
BuildRequires:  python-numpy-devel
## For Patch4
BuildRequires:  libtool
#

%description
NLopt is a free/open-source library for nonlinear optimization,
providing a common interface for a number of different free
optimization routines available online as well as original
implementations of various other algorithms.

%package     -n lib%{name}0
Summary:        A library for nonlinear optimization
Group:          System/Libraries

%description -n lib%{name}0
NLopt is a free/open-source library for nonlinear optimization,
providing a common interface for a number of different free
optimization routines available online as well as original
implementations of various other algorithms.

%package        devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       lib%{name}0 = %{version}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package     -n python-%{name}
Summary:        Python interface to nonlinear optimization libray
Group:          Development/Libraries/Python
Requires:       python-numpy

%description -n python-%{name}
NLopt is a free/open-source library for nonlinear optimization,
providing a common interface for a number of different free
optimization routines available online as well as original
implementations of various other algorithms.

This package contains Python interface to NLopt library.

%package     -n octave-nlopt_optimize
Summary:        Octave interface to nonlinear optimization libray
Group:          Productivity/Scientific/Math
%requires_eq    octave-cli

%description -n octave-nlopt_optimize
NLopt is a free/open-source library for nonlinear optimization,
providing a common interface for a number of different free
optimization routines available online as well as original
implementations of various other algorithms.

This package contains Octave interface to NLopt library.

%prep
%setup -q
%patch1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1

%build
autoreconf -fvi
%configure --enable-shared \
           --disable-static
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
%fdupes %{buildroot}%{py_sitedir}

%post -n lib%{name}0 -p /sbin/ldconfig
%postun -n lib%{name}0 -p /sbin/ldconfig

%files -n lib%{name}0
%{_libdir}/*.so.*

%files devel
%license COPYING
%doc AUTHORS NEWS README TODO
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/%{name}.pc
%{_mandir}/man3/%{name}.*

%files -n python-%{name}
%license COPYING
%{python_sitearch}/*
%{python_sitelib}/*

%files -n octave-nlopt_optimize
%license COPYING
%dir %{_libdir}/octave/*/site
%dir %{_libdir}/octave/*/site/oct
%dir %{_libdir}/octave/*/site/oct/*
%{_libdir}/octave/*/site/oct/*/*.oct
%{_datadir}/octave/*/site/m/*

%changelog
* Sat Jun  2 2018 badshah400@gmail.com
- Add patches to fix compilation against octave 4.4:
  * nlopt-octave4.4-prefixdir.patch: Fix how to find octave's
    prefix dir in configure.ac: octave-config no longer supports
    the keyword PREFIX and uses OCTAVE_HOME in its stead; patch
    being sent upstream. Add BuildRequires: libtool and regenerate
    build files (autoreconf -fvi) before configuring build.
  * nlopt-octave4.4-do_multi_index_op.patch: Replace
    do_multi_index_op by feval; the former is dropped from octave
    4.4; patch being sent upstream.
- Package python modules installed to sitelib as well.
* Thu Jun 23 2016 badshah400@gmail.com
- Use %%requires_eq octave-cli instead of Requires, octave installs
  its files to versioned dirs, so it is important for nlopt to
  be rebuilt for every version update of octave. Making the
  Requires version dependent achieves this.
* Tue Nov 17 2015 dmitry_r@opensuse.org
- Fix compatibility with Octave 4.0
  * nlopt-octave-4.0.patch
* Sun May 31 2015 dmitry_r@opensuse.org
- Disable Octave module due to incompatibility with Octave 4.0
* Thu Nov 13 2014 dmitry_r@opensuse.org
- Update to version 2.4.2
  * Bugfix release, see included NEWS file for details.
- Update package descriptionts.
* Tue Feb 11 2014 badshah400@gmail.com
- Update to version 2.4.1
  - No Linux relevant changes from version 2.4.0
- Changes from version 2.4.0:
  + New genetic algorithm ESCH
  + Fix swig dir for VPATH builds
  + Use python-config program in the configure script to find the
    include directories for Python, if possible (may be overridden
    by PYTHON_CONFIG environment variable)
  + Bugfix in copy constructor for C++ and Python interfaces
  + Bugfix in return value for setting min/max objective
  + Handle negative rescalings in COBYLA and BOBYQA
  + Plugin installation honors the configure --prefix, if any
  + Various compilation fixes for compatibility with recent
    software
- Packaging changes:
  + Minor rebase of pythondir.patch
  + Drop nlopt-2.3-no-return-in-nonvoid-function.patch: corrected
    upstream.
* Tue Sep 10 2013 dvaleev@suse.com
- install python parts to sitearch (pythondir.patch)
* Wed Jun 12 2013 tchvatal@suse.com
- Add fix for .pc file so we can use this library even
  with other projects.
  * nlopt-2.3-pkgconfig.patch
* Sun Feb 24 2013 scorot@free.fr
- remove %%%%clean section
- add minimal single-line comment in spec file for patch0
- add files on %%%%doc section
- spec file cleanup
- add python(abi) requirements recent recent products
- update source url
* Sun Aug 19 2012 scorot@free.fr
- again fix build on x86_64
* Sun Aug 19 2012 scorot@free.fr
- fix build on x86_64
- fix package group names
* Sun Aug 19 2012 scorot@free.fr
- first package
